import typescriptEslint from "@typescript-eslint/eslint-plugin";
import stencilCommunity from "@stencil-community/eslint-plugin";
import jest from "eslint-plugin-jest";
import prettier from "eslint-plugin-prettier";
import globals from "globals";
import path from "node:path";
import { fileURLToPath } from "node:url";
import js from "@eslint/js";
import { FlatCompat } from "@eslint/eslintrc";

const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);
const compat = new FlatCompat({
    baseDirectory: __dirname,
    recommendedConfig: js.configs.recommended,
    allConfig: js.configs.all,
});

export default [
    ...compat.extends(
        "eslint:recommended",
        "plugin:@typescript-eslint/recommended",
        "plugin:@stencil-community/recommended",
        "plugin:prettier/recommended"
    ),
    {
        plugins: {
            "@typescript-eslint": typescriptEslint,
            "@stencil-community": stencilCommunity,
            jest,
            prettier,
        },

        languageOptions: {
            globals: {
                ...globals.jest,
            },

            ecmaVersion: 5,
            sourceType: "script",

            parserOptions: {
                project: "./tsconfig.json",
            },
        },

        rules: {
            "@stencil-community/ban-exported-const-enums": 1,
            "@stencil-community/decorators-context": 0,
            "@stencil-community/decorators-style": 0,
            "@stencil-community/strict-boolean-conditions": 0,
            "@stencil-community/strict-mutable": 0,
            "@typescript-eslint/no-explicit-any": 1,

            "@typescript-eslint/no-unused-vars": [
                "error",
                {
                    varsIgnorePattern: "^h$",
                },
            ],

            "no-extra-boolean-cast": 0,
            "no-unused-vars": 0,
            "react/jsx-no-bind": 0,
            "react/jsx-uses-vars": 2,
        },
    },
    {
        files: ["**/*.ts", "**/*.tsx"],

        rules: {
            "no-undef": "off",
        },
    },
];
